# aladeen-clusterizer

Clusterizing algorithm for news articles

## install dependencies

```sh
poetry env use python3.12
poetry install
source .envrc
```

## run demo

```sh
poetry run python examples/1-example-clustering.py
```
